@@ -272,13 +272,18 @@ class OssFilesPipeline(MediaPipeline):
                 for u in urls:
                     if '%' not in u:
                         #防止资源链接出现空格等特殊字符,eg:https://www.semiee.com/file/Infineon/Infineon-TLE9261-3BQX V33.pdf
-                        u = quote(u, safe='/:&?') 
+                        # u = quote(u, safe='/:&?=#') 
+                        u = u.replace(" ","%20")
                     u = Request(u)
-                    if item._header: 
-                        # 配置资源链接上一请求的header和referer,
-                        # 如果header中包含cookie或响应中包含set-cookie请配置COOKIE_ENABLE=False
+                    # 打开爬虫中间件后,_header不为空,取资源链接上一请求的header和referer,
+                    # 如果header中包含cookie或响应中包含set-cookie请配置COOKIE_ENABLE=False
+                    if '_refer' in item.__dict__:
+                        #爬虫文件中如果给item设置_refer属性在此添加
                         item._header['Referer']=item._refer
-                        u.headers = Headers(item._header, encoding='utf-8')
+                    if '_set_cookies' in item.__dict__:
+                        #爬虫文件中如果给item设置_set_cookies属性在此添加
+                        item._header['Cookie']=item._set_cookies
+                    u.headers = Headers(item._header, encoding='utf-8')
 
                     if self.item_header_dict:
                         # 如果设置自定义ITEM_HEADER优先替换到header
